/*  -- translated by f2c (version 20100827).
   You must link the resulting object file with libf2c:
	on Microsoft Windows system, link with libf2c.lib;
	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
	or, if you install libf2c.a in a standard place, with -lf2c -lm
	-- in that order, at the end of the command line, as in
		cc *.o -lf2c -lm
	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,

		http://www.netlib.org/f2c/libf2c.zip
*/

#include "libtinyf2c.h"

/* ********************************************************************** */
/*     X-DIFFERENTIAL TRANSFORMATION FOR SHMW2S */
/* ********************************************************************** */
/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int shmsri_(integer *mm, integer *m, real *sr, real *si)
{
    /* System generated locals */
    integer sr_offset, si_offset, i__1;

    /* Local variables */
    static integer n;
    static real sid, srd;

    /* Parameter adjustments */
    si_offset = *m;
    si -= si_offset;
    sr_offset = *m;
    sr -= sr_offset;

    /* Function Body */
    i__1 = *mm;
    for (n = *m; n <= i__1; ++n) {
	srd = sr[n];
	sid = si[n];
	sr[n] = sid;
	si[n] = -srd;
/* L10: */
    }
    return 0;
} /* shmsri_ */

